@@ -1,6 +1,10 @@
 """Framework loader for Claude MPM."""
 
+import getpass
+import locale
 import logging
+import os
+import platform
 import time
 from datetime import datetime
 from pathlib import Path
@@ -995,11 +999,8 @@ class FrameworkLoader:
             # Add dynamic agent capabilities section
             instructions += self._generate_agent_capabilities_section()
 
-            # Add current date for temporal awareness
-            instructions += f"\n\n## Temporal Context\n**Today's Date**: {datetime.now().strftime('%Y-%m-%d')}\n"
-            instructions += (
-                "Apply date awareness to all time-sensitive tasks and decisions.\n"
-            )
+            # Add enhanced temporal and user context for better awareness
+            instructions += self._generate_temporal_user_context()
 
             # Add BASE_PM.md framework requirements AFTER INSTRUCTIONS.md
             if self.framework_content.get("base_pm_instructions"):
@@ -1283,6 +1284,14 @@ Extract tickets from these patterns:
                 if agent.get("model") and agent["model"] != "opus":
                     section += f"- **Model**: {agent['model']}\n"
 
+                # Add memory routing information if available
+                if agent.get("memory_routing"):
+                    memory_routing = agent["memory_routing"]
+                    if memory_routing.get("description"):
+                        section += (
+                            f"- **Memory Routing**: {memory_routing['description']}\n"
+                        )
+
             # Add simple Context-Aware Agent Selection
             section += "\n## Context-Aware Agent Selection\n\n"
             section += (
@@ -1314,6 +1323,147 @@ Extract tickets from these patterns:
             self._agent_capabilities_cache_time = current_time
             return result
 
+    def _generate_temporal_user_context(self) -> str:
+        """Generate enhanced temporal and user context for better PM awareness.
+
+        Returns:
+            str: Formatted context string with datetime, user, and system information
+        """
+        context_lines = ["\n\n## Temporal & User Context\n"]
+
+        try:
+            # Get current datetime with timezone awareness
+            now = datetime.now()
+
+            # Try to get timezone info - fallback to UTC offset if timezone name not available
+            try:
+                import time as time_module
+
+                if hasattr(time_module, "tzname"):
+                    tz_name = time_module.tzname[time_module.daylight]
+                    tz_offset = time_module.strftime("%z")
+                    if tz_offset:
+                        # Format UTC offset properly (e.g., -0800 to -08:00)
+                        tz_offset = (
+                            f"{tz_offset[:3]}:{tz_offset[3:]}"
+                            if len(tz_offset) >= 4
+                            else tz_offset
+                        )
+                        tz_info = f"{tz_name} (UTC{tz_offset})"
+                    else:
+                        tz_info = tz_name
+                else:
+                    tz_info = "Local Time"
+            except Exception:
+                tz_info = "Local Time"
+
+            # Format datetime components
+            date_str = now.strftime("%Y-%m-%d")
+            time_str = now.strftime("%H:%M:%S")
+            day_name = now.strftime("%A")
+
+            context_lines.append(
+                f"**Current DateTime**: {date_str} {time_str} {tz_info}\n"
+            )
+            context_lines.append(f"**Day**: {day_name}\n")
+
+        except Exception as e:
+            # Fallback to basic date if enhanced datetime fails
+            self.logger.debug(f"Error generating enhanced datetime context: {e}")
+            context_lines.append(
+                f"**Today's Date**: {datetime.now().strftime('%Y-%m-%d')}\n"
+            )
+
+        try:
+            # Get user information with safe fallbacks
+            username = None
+
+            # Try multiple methods to get username
+            methods = [
+                lambda: os.environ.get("USER"),
+                lambda: os.environ.get("USERNAME"),  # Windows fallback
+                lambda: getpass.getuser(),
+            ]
+
+            for method in methods:
+                try:
+                    username = method()
+                    if username:
+                        break
+                except Exception:
+                    continue
+
+            if username:
+                context_lines.append(f"**User**: {username}\n")
+
+                # Add home directory if available
+                try:
+                    home_dir = os.path.expanduser("~")
+                    if home_dir and home_dir != "~":
+                        context_lines.append(f"**Home Directory**: {home_dir}\n")
+                except Exception:
+                    pass
+
+        except Exception as e:
+            # User detection is optional, don't fail
+            self.logger.debug(f"Could not detect user information: {e}")
+
+        try:
+            # Get system information
+            system_info = platform.system()
+            if system_info:
+                # Enhance system name for common platforms
+                system_names = {
+                    "Darwin": "Darwin (macOS)",
+                    "Linux": "Linux",
+                    "Windows": "Windows",
+                }
+                system_display = system_names.get(system_info, system_info)
+                context_lines.append(f"**System**: {system_display}\n")
+
+                # Add platform version if available
+                try:
+                    platform_version = platform.release()
+                    if platform_version:
+                        context_lines.append(
+                            f"**System Version**: {platform_version}\n"
+                        )
+                except Exception:
+                    pass
+
+        except Exception as e:
+            # System info is optional
+            self.logger.debug(f"Could not detect system information: {e}")
+
+        try:
+            # Add current working directory
+            cwd = os.getcwd()
+            if cwd:
+                context_lines.append(f"**Working Directory**: {cwd}\n")
+        except Exception:
+            pass
+
+        try:
+            # Add locale information if available
+            current_locale = locale.getlocale()
+            if current_locale and current_locale[0]:
+                context_lines.append(f"**Locale**: {current_locale[0]}\n")
+        except Exception:
+            # Locale is optional
+            pass
+
+        # Add instruction for applying context
+        context_lines.append(
+            "\nApply temporal and user awareness to all tasks, "
+            "decisions, and interactions.\n"
+        )
+        context_lines.append(
+            "Use this context for personalized responses and "
+            "time-sensitive operations.\n"
+        )
+
+        return "".join(context_lines)
+
     def _parse_agent_metadata(self, agent_file: Path) -> Optional[Dict[str, Any]]:
         """Parse agent metadata from deployed agent file.
         Uses caching based on file path and modification time.
@@ -1325,7 +1475,7 @@ Extract tickets from these patterns:
             # Check cache based on file path and modification time
             cache_key = str(agent_file)
             file_mtime = agent_file.stat().st_mtime
-            current_time = time.time()
+            time.time()
 
             # Try to get from cache first
             cached_result = self._cache_manager.get_agent_metadata(cache_key)
@@ -1384,6 +1534,14 @@ Extract tickets from these patterns:
                 if routing_data:
                     agent_data["routing"] = routing_data
 
+            # Try to load memory routing metadata from JSON template if not in YAML frontmatter
+            if "memory_routing" not in agent_data:
+                memory_routing_data = self._load_memory_routing_from_template(
+                    agent_file.stem
+                )
+                if memory_routing_data:
+                    agent_data["memory_routing"] = memory_routing_data
+
             # Cache the parsed metadata
             self._cache_manager.set_agent_metadata(cache_key, agent_data, file_mtime)
 
@@ -1393,6 +1551,81 @@ Extract tickets from these patterns:
             self.logger.debug(f"Could not parse metadata from {agent_file}: {e}")
             return None
 
+    def _load_memory_routing_from_template(
+        self, agent_name: str
+    ) -> Optional[Dict[str, Any]]:
+        """Load memory routing metadata from agent JSON template.
+
+        Args:
+            agent_name: Name of the agent (stem of the file)
+
+        Returns:
+            Dictionary with memory routing metadata or None if not found
+        """
+        try:
+            import json
+
+            # Check if we have a framework path
+            if not self.framework_path or self.framework_path == Path("__PACKAGED__"):
+                # For packaged installations, try to load from package resources
+                if files:
+                    try:
+                        templates_package = files("claude_mpm.agents.templates")
+                        template_file = templates_package / f"{agent_name}.json"
+
+                        if template_file.is_file():
+                            template_content = template_file.read_text()
+                            template_data = json.loads(template_content)
+                            return template_data.get("memory_routing")
+                    except Exception as e:
+                        self.logger.debug(
+                            f"Could not load memory routing from packaged template for {agent_name}: {e}"
+                        )
+                return None
+
+            # For development mode, load from filesystem
+            templates_dir = (
+                self.framework_path / "src" / "claude_mpm" / "agents" / "templates"
+            )
+            template_file = templates_dir / f"{agent_name}.json"
+
+            if template_file.exists():
+                with open(template_file) as f:
+                    template_data = json.load(f)
+                    return template_data.get("memory_routing")
+
+            # Also check for variations in naming (underscore vs dash)
+            # Handle common naming variations between deployed .md files and .json templates
+            # Remove duplicates by using a set
+            alternative_names = list(
+                {
+                    agent_name.replace("-", "_"),  # api-qa -> api_qa
+                    agent_name.replace("_", "-"),  # api_qa -> api-qa
+                    agent_name.replace("-", ""),  # api-qa -> apiqa
+                    agent_name.replace("_", ""),  # api_qa -> apiqa
+                    agent_name.replace("-agent", ""),  # research-agent -> research
+                    agent_name.replace("_agent", ""),  # research_agent -> research
+                    agent_name + "_agent",  # research -> research_agent
+                    agent_name + "-agent",  # research -> research-agent
+                }
+            )
+
+            for alt_name in alternative_names:
+                if alt_name != agent_name:  # Skip the original name we already tried
+                    alt_file = templates_dir / f"{alt_name}.json"
+                    if alt_file.exists():
+                        with open(alt_file) as f:
+                            template_data = json.load(f)
+                            return template_data.get("memory_routing")
+
+            return None
+
+        except Exception as e:
+            self.logger.debug(
+                f"Could not load memory routing from template for {agent_name}: {e}"
+            )
+            return None
+
     def _load_routing_from_template(self, agent_name: str) -> Optional[Dict[str, Any]]:
         """Load routing metadata from agent JSON template.
 
